@@ -7,12 +7,12 @@ from tqdm import tqdm_notebook as tqdm
 from IPython.display import clear_output
 import tarfile
 
-from evaluation_metrics import ClassifierReport
-from pytorch_device_manager import  DeviceManager
-from pytorch_data_transformation import NCenterCrop
+from .evaluation_metrics import ClassifierReport
+from .pytorch_device_manager import  DeviceManager
+from .pytorch_data_transformation import NCenterCrop
 
-from utilities import ElapsedTime
-from lr_finder import LRFinder
+from .utilities import ElapsedTime
+from .lr_finder import LRFinder
 
 import torch
 import torch.nn as nn
@@ -898,10 +898,10 @@ class ModelTraining:
         
         return layers
             
-    def display_misclassification(self, model_name, dataset):
+    def display_misclassification(self, model_name, dataset, to_display=10):
         with open(model_name, 'rb') as f:
             model_training = pk.load(f)
             
-        ClassificationAnalysis.misclassification(model_training, dataset)
+        ClassificationAnalysis.misclassification(model_training, dataset, to_display)
 
 
